clear all
close all
clc

addpath(genpath('./spectral_tv/'));

% Obtain size of a sample image
sample       = rgb2gray(im2double(imread('../data/facility/data_0001.png')));
[rows, cols] = size(sample);
frames       = 20;

% Load images
hyper_true   = zeros(rows, cols, frames);
for i=1:frames
    fname = ['../data/facility/data_00', num2str(i, '%02g'), '.png'];
    hyper_true(:,:,i) = rgb2gray(im2double(imread(fname)));
end

% Add noise in the images
sigma_true   = 0.02:0.02:(0.02*frames);
hyper_noisy  = zeros(rows, cols, frames);
for i=1:frames
    hyper_noisy(:,:,i) = hyper_true(:,:,i) + sigma_true(i)*randn(rows, cols);
end


% Spectral Total Variation
opts.beta   = [1 1 0.1];
runtime     = tic;
out_stv     = spectral_tv(hyper_noisy, opts);
runtime_stv = toc(runtime);
sigma_est   = out_stv.sigma;
psnr_stv    = psnr(hyper_true, out_stv.f);


% Original Total Variation
mu          = 1;
opts.w      = mean(out_stv.w(:));
opts.beta   = [1 1 0.1];
runtime     = tic;
out_tv      = deconvtvl2(hyper_noisy, 1, mu, opts);
runtime_tv  = toc(runtime);
psnr_tv     = psnr(hyper_true, out_tv.f);


% Print PSNRs between true and denoised images.
fprintf('Method: spectral tv, \t psnr: %6.4f\n', psnr_stv);
% fprintf('Method: original tv, \t psnr: %6.4f, \t runtime: %6.4f\n', psnr_tv, runtime_tv);

% Plot the true and estimeated noise level.
figure;
plot(sigma_true, 'LineWidth', 2, 'Color', 'g');
hold on;
plot(sigma_est, 'LineWidth', 2, 'Color', 'r');
hold off;
xlabel('frame');
ylabel('noise standard deviation');
legend('True', 'Estimated', 'Location', 'best');
